==> localstack-ext-1.4.1.dev20230214104950.tar.gz: localstack-ext-1.4.1.dev20230214104950/localstack_ext/bootstrap/pods/object_storage.py <==
_B='_none_'
_A='local'
import abc,logging,os
from typing import List
import yaml
from localstack.utils.files import load_file
from localstack_ext.bootstrap.pods.constants import VERSION_FILE
from localstack_ext.bootstrap.pods.models import PodObject,Version
from localstack_ext.bootstrap.pods.utils.common import PodsConfigContext
from localstack_ext.bootstrap.pods.utils.serializers import PodsSerializerYaml
LOG=logging.getLogger(__name__)
class StateFileLocator(abc.ABC):
	location=_B;active_instance=None
	@abc.abstractmethod
	def get_state_file_location_by_key(self,key,obj_store_path):0
	@classmethod
	def get(A,requested_file_locator):
		B=requested_file_locator
		if not A.active_instance or A.active_instance.location!=B:
			for C in A.__subclasses__():
				if C.location==B:A.active_instance=C()
		return A.active_instance
class StateFileLocatorLocal(StateFileLocator):
	location=_A
	def get_state_file_location_by_key(A,key,obj_store_path):return os.path.join(obj_store_path,key)
class ObjectStorageProvider(abc.ABC):
	location=_B;active_instance=None
	@classmethod
	def get(A,state_file_locator,requested_storage,config_context):
		D=config_context;C=requested_storage;B=state_file_locator
		if not A.active_instance or A.active_instance.location!=C:
			B=StateFileLocator.get(requested_file_locator=B)
			for E in A.__subclasses__():
				if E.location==C:A.active_instance=E(state_file_locator=B,config_context=D)
		A.active_instance.config_context=D;return A.active_instance
	def __init__(A,state_file_locator,config_context):A.state_file_locator=state_file_locator;A.config_context=config_context;A.serializer=PodsSerializerYaml()
	@abc.abstractmethod
	def get_state_file_location_by_key(self,key):0
	@abc.abstractmethod
	def get_delta_file_by_key(self,key,get_delta_file_by_key):0
	@abc.abstractmethod
	def upsert_objects(self,*A):0
	@abc.abstractmethod
	def get_version(self,version_number):0
	@abc.abstractmethod
	def version_exists(self,version_number):0
	@abc.abstractmethod
	def _serialize(self,*A):0
	@property
	def version_store_path(self):return self.config_context.get_versions_path()
	@property
	def object_store_path(self):return self.config_context.get_obj_store_path()
class ObjectStorageLocal(ObjectStorageProvider):
	location=_A
	def get_state_file_location_by_key(A,key):return A.state_file_locator.get_state_file_location_by_key(obj_store_path=A.object_store_path,key=key)
	def get_delta_file_by_key(B,key,delta_log_path):
		A=os.path.join(delta_log_path,key)
		if os.path.isfile(A):return A
		LOG.warning('No state file found for key: %s',key)
	def upsert_objects(A,*B):return A._serialize(*(B))
	def version_exists(A,version_number):return os.path.isfile(A._version_file_path(version_number))
	def get_version(C,version_number):
		A=version_number;B=C._version_file_path(A)
		if not os.path.isfile(B):raise Exception(f"Unable to find cloud pod version {A}")
		D=yaml.safe_load(load_file(B));return Version.from_dict(D)
	def _version_file_path(A,version_number):return os.path.join(A.version_store_path,VERSION_FILE.format(version_no=version_number))
	def _serialize(B,*D):
		C=[]
		for A in D:
			if isinstance(A,Version):E=B.serializer.store_version(A,B.version_store_path);C.append(E)
			else:raise Exception(f"Unexpected pod object passed for serialization: {A}")
		return C
def get_object_storage_provider(config_context,requested_storage=_A):A=requested_storage;return ObjectStorageProvider.get(state_file_locator=A,requested_storage=A,config_context=config_context)

==> localstack-ext-2.0.3.dev20230516084829.tar.gz: localstack-ext-2.0.3.dev20230516084829/localstack_ext/bootstrap/pods/object_storage.py <==
_B='_none_'
_A='local'
import abc,logging,os
from typing import List
import yaml
from localstack.utils.files import load_file
from localstack_ext.bootstrap.pods.constants import VERSION_FILE
from localstack_ext.bootstrap.pods.models import PodObject,Version
from localstack_ext.bootstrap.pods.utils.common import PodsConfigContext
from localstack_ext.bootstrap.pods.utils.serializers import PodsSerializerYaml
LOG=logging.getLogger(__name__)
class StateFileLocator(abc.ABC):
	location=_B;active_instance=None
	@abc.abstractmethod
	def get_state_file_location_by_key(self,key,obj_store_path):0
	@classmethod
	def get(A,requested_file_locator):
		B=requested_file_locator
		if not A.active_instance or A.active_instance.location!=B:
			for C in A.__subclasses__():
				if C.location==B:A.active_instance=C()
		return A.active_instance
class StateFileLocatorLocal(StateFileLocator):
	location=_A
	def get_state_file_location_by_key(A,key,obj_store_path):return os.path.join(obj_store_path,key)
class ObjectStorageProvider(abc.ABC):
	location=_B;active_instance=None
	@classmethod
	def get(A,state_file_locator,requested_storage,config_context):
		D=config_context;C=requested_storage;B=state_file_locator
		if not A.active_instance or A.active_instance.location!=C:
			B=StateFileLocator.get(requested_file_locator=B)
			for E in A.__subclasses__():
				if E.location==C:A.active_instance=E(state_file_locator=B,config_context=D)
		A.active_instance.config_context=D;return A.active_instance
	def __init__(A,state_file_locator,config_context):A.state_file_locator=state_file_locator;A.config_context=config_context;A.serializer=PodsSerializerYaml()
	@abc.abstractmethod
	def get_state_file_location_by_key(self,key):0
	@abc.abstractmethod
	def upsert_objects(self,*A):0
	@abc.abstractmethod
	def get_version(self,version_number):0
	@abc.abstractmethod
	def version_exists(self,version_number):0
	@abc.abstractmethod
	def get_available_versions(self):0
	@abc.abstractmethod
	def get_current_active_version_number(self):0
	@property
	def version_store_path(self):return self.config_context.get_versions_path()
	@property
	def object_store_path(self):return self.config_context.get_obj_store_path()
class ObjectStorageLocal(ObjectStorageProvider):
	location=_A
	def get_state_file_location_by_key(A,key):return A.state_file_locator.get_state_file_location_by_key(obj_store_path=A.object_store_path,key=key)
	def upsert_objects(A,*B):return A._serialize(*B)
	def version_exists(A,version_number):return os.path.isfile(A._version_file_path(version_number))
	def get_available_versions(B):
		C=[];A=Version.DEFAULT_INITIAL_VERSION_NUMBER
		while True:
			if not B.version_exists(A):return C
			D=B.get_version(A)
			if D.finalized:C.append(A)
			A+=1
	def get_current_active_version_number(B):
		C=B.get_available_versions();A=C[-1]if C else Version.DEFAULT_INITIAL_VERSION_NUMBER
		if B.version_exists(A+1):return A+1
		return A
	def get_version(C,version_number):
		A=version_number;B=C._version_file_path(A)
		if not os.path.isfile(B):raise Exception(f"Unable to find cloud pod version {A}")
		D=yaml.safe_load(load_file(B));return Version.from_dict(D)
	def _version_file_path(A,version_number):return os.path.join(A.version_store_path,VERSION_FILE.format(version_no=version_number))
	def _serialize(B,*D):
		C=[]
		for A in D:
			if isinstance(A,Version):E=B.serializer.store_version(A,B.version_store_path);C.append(E)
			else:raise Exception(f"Unexpected pod object passed for serialization: {A}")
		return C
def get_object_storage_provider(config_context,requested_storage=_A):A=requested_storage;return ObjectStorageProvider.get(state_file_locator=A,requested_storage=A,config_context=config_context)
